Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(416)

Unified Diff: services/ui/ws/gpu_host.h

Issue 2797453002: Rename DisplayCompositor to MojoFrameSinkManager. (Closed)
Patch Set: Fix comments. Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: services/ui/ws/gpu_host.h
diff --git a/services/ui/ws/gpu_host.h b/services/ui/ws/gpu_host.h
index 628726e887cda938d9ee224abe0c3a3fda30dd36..bb0e0a6372da42d25d7e875bdfc8b233f1144e59 100644
--- a/services/ui/ws/gpu_host.h
+++ b/services/ui/ws/gpu_host.h
@@ -44,9 +44,9 @@ class GpuHost : public mojom::GpuHost {
void OnAcceleratedWidgetAvailable(gfx::AcceleratedWidget widget);
void OnAcceleratedWidgetDestroyed(gfx::AcceleratedWidget widget);
- // Requests a cc::mojom::DisplayCompositor interface from mus-gpu.
- void CreateDisplayCompositor(cc::mojom::DisplayCompositorRequest request,
- cc::mojom::DisplayCompositorClientPtr client);
+ // Requests a cc::mojom::FrameSinkManager interface from mus-gpu.
+ void CreateFrameSinkManager(cc::mojom::FrameSinkManagerRequest request,
+ cc::mojom::FrameSinkManagerClientPtr client);
private:
friend class test::GpuHostTest;

Powered by Google App Engine
This is Rietveld 408576698